<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES">
<context>
    <name>Database</name>
    <message>
        <location filename="../../libs/utils/database.cpp" line="496"/>
        <source>WARNING : %1 database already in use</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/database.cpp" line="657"/>
        <source>ERROR : Database %1 is not readable. Path : %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/database.cpp" line="649"/>
        <source>ERROR : Database %1 is not readable. Host: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/database.cpp" line="639"/>
        <source>ERROR : Database `%1` is not readable. Path : %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/database.cpp" line="684"/>
        <source>ERROR : Database %1 is not writable. Path : %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/database.cpp" line="725"/>
        <source>INFO : database %1 connection = %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/database.cpp" line="915"/>
        <source>Database Scheme Error : wrong number of fields for table %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/database.cpp" line="924"/>
        <source>Database Scheme Error : field number %1 differs : %2 instead of %3 in table %4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/database.cpp" line="1716"/>
        <source>Can not create table %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LineEditEchoSwitcher</name>
    <message>
        <location filename="../../libs/utils/widgets/lineeditechoswitcher.cpp" line="62"/>
        <source>Display/Hide text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Log</name>
    <message>
        <location filename="../../libs/utils/log.cpp" line="113"/>
        <source>SQL Error : Driver : %1, Database : %2, Query : %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/log.cpp" line="118"/>
        <source>%1 : %2 - SQL Error : Driver : %3, Database : %4, Query : %5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/log.cpp" line="135"/>
        <source>%1 : %2 - Database: %3, Host: %4, Port: %5, User:%6, Pass:%7</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/log.cpp" line="149"/>
        <source>%1 ms : %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/log.cpp" line="222"/>
        <source>Unable to save %1 : Error %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/log.cpp" line="237"/>
        <source>Debugging informations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/log.cpp" line="242"/>
        <source>********** ERRORS *********
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/log.cpp" line="261"/>
        <source>********** MESSAGES *********
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QAbstractXmlTreeModel</name>
    <message>
        <location filename="../../libs/utils/qabstractxmltreemodel.cpp" line="92"/>
        <source>Can not read XML file content %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/qabstractxmltreemodel.cpp" line="95"/>
        <source>Reading file: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/qabstractxmltreemodel.cpp" line="99"/>
        <source>Can not open XML file %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Serializer</name>
    <message>
        <location filename="../../libs/utils/serializer.cpp" line="269"/>
        <location filename="../../libs/utils/serializer.cpp" line="330"/>
        <location filename="../../libs/utils/serializer.cpp" line="388"/>
        <source>Can not deserialize to QHash.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../../libs/utils/global.cpp" line="392"/>
        <location filename="../../libs/utils/global.cpp" line="395"/>
        <source>Error while retrieve informations of uname under %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="519"/>
        <source>%1 : %2 does not exist. Trying to create it.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="522"/>
        <source>Unable to create the %1 : %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="528"/>
        <source>%1 : %2 does not exist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="560"/>
        <source>File %1 already exists. Do you want de replace it ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="565"/>
        <location filename="../../libs/utils/global.cpp" line="571"/>
        <location filename="../../libs/utils/global.cpp" line="587"/>
        <source>Error %1 while trying to save file %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="579"/>
        <location filename="../../libs/utils/global.cpp" line="592"/>
        <source>%1 correctly saved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="581"/>
        <source>Save file aborted by user (file already exists) : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="604"/>
        <source>Save to file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="638"/>
        <source>File %1 does not exists or is not readable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="644"/>
        <source>Error %1 while trying to open file %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="798"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="873"/>
        <source>This function is not available in this version.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="874"/>
        <source>You can send an email to developpers and explain your difficulties : freemedforms@googlegroups.com.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="915"/>
        <location filename="../../libs/utils/global.cpp" line="916"/>
        <source>License agreement acceptation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="927"/>
        <source>&lt;b&gt;Before you can use this software, you must agree its license terms&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="935"/>
        <source>Do you agree these terms ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="1004"/>
        <source>%1 is now in fullScreen Mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="1009"/>
        <source>%1 is now in non fullScreen Mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="1521"/>
        <source>Token replacement error (%1). Wrong number of parentheses.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Utils::FileNameValidatingLineEdit</name>
    <message>
        <location filename="../../libs/utils/widgets/filenamevalidatinglineedit.cpp" line="95"/>
        <source>Name is empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/widgets/filenamevalidatinglineedit.cpp" line="104"/>
        <source>Name contains white space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/widgets/filenamevalidatinglineedit.cpp" line="106"/>
        <source>Invalid character &apos;%1&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/widgets/filenamevalidatinglineedit.cpp" line="117"/>
        <source>Invalid characters &apos;%1&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/widgets/filenamevalidatinglineedit.cpp" line="127"/>
        <source>Name matches MS Windows device. (%1).</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Utils::HttpDownloader</name>
    <message>
        <location filename="../../libs/utils/httpdownloader.cpp" line="92"/>
        <source>Start downloading: %1 to %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/httpdownloader.cpp" line="111"/>
        <source>There already exists a file called %1 in the current directory. Overwrite?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/httpdownloader.cpp" line="121"/>
        <location filename="../../libs/utils/httpdownloader.cpp" line="127"/>
        <source>Unable to save the file %1: %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/httpdownloader.cpp" line="133"/>
        <location filename="../../libs/utils/httpdownloader.cpp" line="178"/>
        <location filename="../../libs/utils/httpdownloader.cpp" line="188"/>
        <source>HTTP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/httpdownloader.cpp" line="135"/>
        <source>Downloading %1
To %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/httpdownloader.cpp" line="179"/>
        <location filename="../../libs/utils/httpdownloader.cpp" line="182"/>
        <source>Download failed: %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/httpdownloader.cpp" line="189"/>
        <source>Redirect to %1 ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/httpdownloader.cpp" line="208"/>
        <source>Downloaded %1 to current directory.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Utils::Internal::UpdateCheckerPrivate</name>
    <message>
        <location filename="../../libs/utils/updatechecker.cpp" line="107"/>
        <source>Error %1 while retreiving update file %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/updatechecker.cpp" line="131"/>
        <source>* Updates of version : %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Utils::PathChooser</name>
    <message>
        <location filename="../../libs/utils/widgets/pathchooser.cpp" line="49"/>
        <source>Choose...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/widgets/pathchooser.cpp" line="51"/>
        <source>Browse...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/widgets/pathchooser.cpp" line="174"/>
        <source>Choose Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/widgets/pathchooser.cpp" line="180"/>
        <source>Choose File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/widgets/pathchooser.cpp" line="213"/>
        <source>The path must not be empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/widgets/pathchooser.cpp" line="225"/>
        <source>The path &apos;%1&apos; does not exist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/widgets/pathchooser.cpp" line="240"/>
        <source>The path &apos;%1&apos; is not a directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/widgets/pathchooser.cpp" line="248"/>
        <source>The path &apos;%1&apos; is not a file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libs/utils/widgets/pathchooser.cpp" line="267"/>
        <source>Path:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Utils::QButtonLineEdit</name>
    <message>
        <location filename="../../libs/utils/widgets/qbuttonlineedit.cpp" line="187"/>
        <source>(press Alt up/down cursor to cycle)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Utils::UpdateChecker</name>
    <message>
        <location filename="../../libs/utils/updatechecker.cpp" line="279"/>
        <source>An update is available. Please check the web site : &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
